@@ -8,4 +8,4 @@
 
 EXTERN struct flags_s list;	/* listing on/off */
 EXTERN struct flags_s maclist;	/* list macros on/off */
-EXTERN struct flags_s warn;	/* warnings on/off */
+EXTERN struct flags_s warning;	/* warnings on/off */
