@@ -909,7 +909,7 @@ PUBLIC void ptext()
 
 PUBLIC void pwarn()
 {
-    bumpsem(&warn);
+    bumpsem(&warning);
 }
 
 #ifdef I80386
