@@ -184,9 +184,9 @@ PUBLIC void pproceof()
 	list.current = list.global;
 	maclist.current = maclist.global;
 
-	warn.current = TRUE;
-	if (warn.semaphore < 0)
-	    warn.current = FALSE;
+	warning.current = TRUE;
+	if (warning.semaphore < 0)
+	    warning.current = FALSE;
 	if (infiln != 0)
 	    infil = open_input(filnamptr);
 	binheader();
