@@ -9,6 +9,6 @@
 #ifndef S_ALIGNMENT
 # define align(x)
 #else
-# define align(x) ((x) = ((int) (x) + (S_ALIGNMENT-1)) & ~(S_ALIGNMENT-1))
+# define align(x) ((x) = (void *)(((int) (x) + (S_ALIGNMENT-1)) & ~(S_ALIGNMENT-1)))
 				/* assumes sizeof(int) == sizeof(char *) */
 #endif
